text = """
Example Text:

<red>This somewhat depends on what platform you are on.</red>
The most <yellow>common</yellow> way to do this is <blue>by printing ANSI escape sequences.</blue> 
For a simple example, see this color map:

<black>black</black>
<red>red</red>
<green>green</green>
<yellow>yellow</yellow>
<blue>blue</blue>
<magenta>magenta</magenta>
<cyan>cyan</cyan>
<lightgray>lightgray</lightgray>
<darkgray>darkgray</darkgray>
<lightred>lightred</lightred>
<lightgreen>lightgreen</lightgreen>
<lightyellow>lightyellow</lightyellow>
<lightblue>lightblue</lightblue>
<lightmagenta>lightmagenta</lightmagenta>
<lightcyan>lightcyan</lightcyan>
<white>white</white>
"""

# text = "<green>TASIN IS REALLY COOL</green> Also: <blue>Ethan is cool i guess</blue>"